@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of refextract.
-# Copyright (C) 2013, 2015, 2016, 2018 CERN.
+# Copyright (C) 2013, 2015, 2016, 2018, 2020 CERN.
 #
 # refextract is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -23,23 +23,21 @@
 
 """Various utilities to manipulate or clean text"""
 
-from __future__ import absolute_import, division, print_function
-
 import re
-from six.moves import xrange
 
-re_space_comma = re.compile(ur'\s,', re.UNICODE)
-re_space_semicolon = re.compile(ur'\s;', re.UNICODE)
-re_space_period = re.compile(ur'\s\.', re.UNICODE)
-re_colon_space_colon = re.compile(ur':\s:', re.UNICODE)
-re_comma_space_colon = re.compile(ur',\s:', re.UNICODE)
-re_space_closing_square_bracket = re.compile(ur'\s\]', re.UNICODE)
-re_opening_square_bracket_space = re.compile(ur'\[\s', re.UNICODE)
+
+re_space_comma = re.compile(r'\s,', re.UNICODE)
+re_space_semicolon = re.compile(r'\s;', re.UNICODE)
+re_space_period = re.compile(r'\s\.', re.UNICODE)
+re_colon_space_colon = re.compile(r':\s:', re.UNICODE)
+re_comma_space_colon = re.compile(r',\s:', re.UNICODE)
+re_space_closing_square_bracket = re.compile(r'\s\]', re.UNICODE)
+re_opening_square_bracket_space = re.compile(r'\[\s', re.UNICODE)
 re_hyphens = re.compile(
-    ur'(\\255|\u02D7|\u0335|\u0336|\u2212|\u002D|\uFE63|\uFF0D)', re.UNICODE)
-re_multiple_space = re.compile(ur'\s{2,}', re.UNICODE)
+    br'(\\255|\u02D7|\u0335|\u0336|\u2212|\u002D|\uFE63|\uFF0D)'.decode('raw_unicode_escape'), re.UNICODE)
+re_multiple_space = re.compile(r'\s{2,}', re.UNICODE)
 
-re_group_captured_multiple_space = re.compile(ur'(\s{2,})', re.UNICODE)
+re_group_captured_multiple_space = re.compile(r'(\s{2,})', re.UNICODE)
 
 
 def get_url_repair_patterns():
@@ -50,38 +48,38 @@ def get_url_repair_patterns():
         various broken URLs.
     """
     file_types_list = [
-        ur'h\s*t\s*m',          # htm
-        ur'h\s*t\s*m\s*l',      # html
-        ur't\s*x\s*t'           # txt
-        ur'p\s*h\s*p'           # php
-        ur'a\s*s\s*p\s*'        # asp
-        ur'j\s*s\s*p',          # jsp
-        ur'p\s*y',              # py (python)
-        ur'p\s*l',              # pl (perl)
-        ur'x\s*m\s*l',          # xml
-        ur'j\s*p\s*g',          # jpg
-        ur'g\s*i\s*f'           # gif
-        ur'm\s*o\s*v'           # mov
-        ur's\s*w\s*f'           # swf
-        ur'p\s*d\s*f'           # pdf
-        ur'p\s*s'               # ps
-        ur'd\s*o\s*c',          # doc
-        ur't\s*e\s*x',          # tex
-        ur's\s*h\s*t\s*m\s*l',  # shtml
+        r'h\s*t\s*m',          # htm
+        r'h\s*t\s*m\s*l',      # html
+        r't\s*x\s*t',          # txt
+        r'p\s*h\s*p',          # php
+        r'a\s*s\s*p\s*',       # asp
+        r'j\s*s\s*p',          # jsp
+        r'p\s*y',              # py (python)
+        r'p\s*l',              # pl (perl)
+        r'x\s*m\s*l',          # xml
+        r'j\s*p\s*g',          # jpg
+        r'g\s*i\s*f',          # gif
+        r'm\s*o\s*v',          # mov
+        r's\s*w\s*f',          # swf
+        r'p\s*d\s*f',          # pdf
+        r'p\s*s',              # ps
+        r'd\s*o\s*c',          # doc
+        r't\s*e\s*x',          # tex
+        r's\s*h\s*t\s*m\s*l',  # shtml
     ]
 
     pattern_list = [
-        ur'(h\s*t\s*t\s*p\s*\:\s*\/\s*\/)',
-        ur'(f\s*t\s*p\s*\:\s*\/\s*\/\s*)',
-        ur'((http|ftp):\/\/\s*[\w\d])',
-        ur'((http|ftp):\/\/([\w\d\s\._\-])+?\s*\/)',
-        ur'((http|ftp):\/\/([\w\d\_\.\-])+\/(([\w\d\_\s\.\-])+?\/)+)',
-        ur'((http|ftp):\/\/([\w\d\_\.\-])+\/(([\w\d\_\s\.\-])+?\/)*([\w\d\_\s\-]+\.\s?[\w\d]+))',
+        r'(h\s*t\s*t\s*p\s*\:\s*\/\s*\/)',
+        r'(f\s*t\s*p\s*\:\s*\/\s*\/\s*)',
+        r'((http|ftp):\/\/\s*[\w\d])',
+        r'((http|ftp):\/\/([\w\d\s\._\-])+?\s*\/)',
+        r'((http|ftp):\/\/([\w\d\_\.\-])+\/(([\w\d\_\s\.\-])+?\/)+)',
+        r'((http|ftp):\/\/([\w\d\_\.\-])+\/(([\w\d\_\s\.\-])+?\/)*([\w\d\_\s\-]+\.\s?[\w\d]+))',
     ]
     pattern_list = [re.compile(p, re.I | re.UNICODE) for p in pattern_list]
 
     # some possible endings for URLs:
-    p = ur'((http|ftp):\/\/([\w\d\_\.\-])+\/(([\w\d\_\.\-])+?\/)*([\w\d\_\-]+\.%s))'
+    p = r'((http|ftp):\/\/([\w\d\_\.\-])+\/(([\w\d\_\.\-])+?\/)*([\w\d\_\-]+\.%s))'
     for extension in file_types_list:
         p_url = re.compile(p % extension, re.I | re.UNICODE)
         pattern_list.append(p_url)
@@ -243,9 +241,9 @@ def get_page_break_positions(docbody):
         position (in the document body) of a page-break.
     """
     page_break_posns = []
-    p_break = re.compile(ur'^\s*\f\s*$', re.UNICODE)
+    p_break = re.compile(r'^\s*\f\s*$', re.UNICODE)
     num_document_lines = len(docbody)
-    for i in xrange(num_document_lines):
+    for i in range(num_document_lines):
         if p_break.match(docbody[i]) is not None:
             page_break_posns.append(i)
     return page_break_posns
@@ -264,7 +262,7 @@ def get_number_header_lines(docbody, page_break_posns):
     remaining_breaks = len(page_break_posns) - 1
     num_header_lines = empty_line = 0
     # pattern to search for a word in a line:
-    p_wordSearch = re.compile(ur'([A-Za-z0-9-]+)', re.UNICODE)
+    p_wordSearch = re.compile(r'([A-Za-z0-9-]+)', re.UNICODE)
     if remaining_breaks > 2:
         if remaining_breaks > 3:
             # Only check odd page headers
@@ -334,7 +332,7 @@ def get_number_footer_lines(docbody, page_break_posns):
     num_footer_lines = 0
     empty_line = 0
     keep_checking = 1
-    p_wordSearch = re.compile(unicode(r'([A-Za-z0-9-]+)'), re.UNICODE)
+    p_wordSearch = re.compile(r'([A-Za-z0-9-]+)', re.UNICODE)
     if num_breaks > 2:
         while keep_checking:
             cur_break = 1
@@ -396,7 +394,7 @@ def strip_headers_footers_pagebreaks(docbody,
     """
     num_breaks = len(page_break_posns)
     page_lens = []
-    for x in xrange(0, num_breaks):
+    for x in range(0, num_breaks):
         if x < num_breaks - 1:
             page_lens.append(page_break_posns[x + 1] - page_break_posns[x])
     page_lens.sort()
@@ -405,10 +403,10 @@ def strip_headers_footers_pagebreaks(docbody,
         # Safe to chop hdrs & ftrs
         page_break_posns.reverse()
         first = 1
-        for i in xrange(0, len(page_break_posns)):
+        for i in range(0, len(page_break_posns)):
             # Unless this is the last page break, chop headers
             if not first:
-                for dummy in xrange(1, num_head_lines + 1):
+                for dummy in range(1, num_head_lines + 1):
                     docbody[page_break_posns[i] +
                             1:page_break_posns[i] + 2] = []
             else:
@@ -417,7 +415,7 @@ def strip_headers_footers_pagebreaks(docbody,
             docbody[page_break_posns[i]:page_break_posns[i] + 1] = []
             # Chop footers (unless this is the first page break)
             if i != len(page_break_posns) - 1:
-                for dummy in xrange(1, num_foot_lines + 1):
+                for dummy in range(1, num_foot_lines + 1):
                     docbody[page_break_posns[i] -
                             num_foot_lines:page_break_posns[i] -
                             num_foot_lines + 1] = []
@@ -436,7 +434,7 @@ def check_boundary_lines_similar(l_1, l_2):
         return 0
 
     num_elements = len(l_1)
-    for i in xrange(0, num_elements):
+    for i in range(0, num_elements):
         if l_1[i].isdigit() and l_2[i].isdigit():
             # both lines are integers
             num_matches += 1
