@@ -23,10 +23,7 @@
 
 """Main engine responsible for extracting references from PDF documents."""
 
-from __future__ import absolute_import, division, print_function
-
 import logging
-import mmap
 import re
 
 from datetime import datetime
@@ -174,7 +171,7 @@ def format_report_number(citation_elements):
 
     e.g. CERN-LCHH2003-01 to CERN-LHCC-2003-01
     """
-    re_report = re.compile(ur'^(?P<name>[A-Z-]+)(?P<nums>[\d-]+)$', re.UNICODE)
+    re_report = re.compile(r'^(?P<name>[A-Z-]+)(?P<nums>[\d-]+)$', re.UNICODE)
     for el in citation_elements:
         if el['type'] == 'REPORTNUMBER':
             m = re_report.match(el['report_num'])
@@ -273,7 +270,7 @@ def mangle_volume(citation_elements):
 
     e.g. transforms 100B to B100
     """
-    volume_re = re.compile(ur"(\d+)([A-Z])", re.U | re.I)
+    volume_re = re.compile(r"(\d+)([A-Z])", re.U | re.I)
     for el in citation_elements:
         if el['type'] == 'JOURNAL':
             matches = volume_re.match(el['volume'])
@@ -1381,7 +1378,7 @@ def remove_leading_garbage_lines_from_reference_section(ref_sectn):
        @return: (list) of strings - the reference section without leading
         blank lines or email addresses.
     """
-    p_email = re.compile(ur'^\s*e\-?mail', re.UNICODE)
+    p_email = re.compile(r'^\s*e\-?mail', re.UNICODE)
     while ref_sectn and (ref_sectn[0].isspace() or p_email.match(ref_sectn[0])):
         ref_sectn.pop(0)
     return ref_sectn
@@ -1392,32 +1389,6 @@ def remove_leading_garbage_lines_from_reference_section(ref_sectn):
 
 # Tasks related to conversion of full-text to plain-text:
 
-def clean_pdf_file(filename):
-    """
-    strip leading and/or trailing junk from a PDF file
-    """
-    with open(filename, 'rb+') as file:
-        try:
-            mmfile = mmap.mmap(file.fileno(), 0, access=mmap.ACCESS_WRITE)
-            start = mmfile.find(b'%PDF-')
-            if start == -1:
-                # no PDF marker found
-                LOGGER.debug('not a PDF file')
-                return
-            end = mmfile.rfind(b'%%EOF')
-            offset = len(b'%%EOF')
-            if start > 0:
-                LOGGER.debug('moving and truncating')
-                mmfile.move(0, start, end + offset - start)
-                mmfile.resize(end + offset - start)
-                mmfile.flush()
-            elif end > 0 and end + offset != mmfile.size():
-                LOGGER.debug('truncating only')
-                mmfile.resize(end + offset - start)
-                mmfile.flush()
-        finally:
-            mmfile.close()
-
 
 def get_plaintext_document_body(fpath, keep_layout=False):
     """Given a file-path to a full-text, return a list of unicode strings
@@ -1431,12 +1402,11 @@ def get_plaintext_document_body(fpath, keep_layout=False):
        @return: (list) of strings - each string being a line in the document.
     """
     textbody = []
-    clean_pdf_file(fpath)
     mime_type = magic.from_file(fpath, mime=True)
 
     if mime_type == "text/plain":
         with open(fpath, "r") as f:
-            textbody = [line.decode("utf-8") for line in f.readlines()]
+            textbody = f.readlines()
 
     elif mime_type == "application/pdf":
         textbody = convert_PDF_to_plaintext(fpath, keep_layout)
@@ -1458,7 +1428,7 @@ def parse_references(reference_lines,
     output a list of dictionaries containing the parsed references
     """
     # RefExtract knowledge bases
-    kbs = get_kbs(custom_kbs_files=override_kbs_files)
+    kbs = get_kbs(custom_kbs=override_kbs_files)
     # Identify journal titles, report numbers, URLs, DOIs, and authors...
     processed_references, counts, dummy_bad_titles_count = \
         parse_references_elements(reference_lines, kbs, linker_callback)
