@@ -21,17 +21,12 @@
 # granted to it by virtue of its status as an Intergovernmental Organization
 # or submit itself to any jurisdiction.
 
-from __future__ import absolute_import, division, print_function
-
 import re
 import six
 import csv
 import codecs
 import contextlib
 
-from hashlib import md5
-from six import iteritems
-
 from .config import CFG_REFEXTRACT_KBS
 from .regexs import (
     re_kb_line,
@@ -48,7 +43,7 @@ def file_resolving(fpath, reader=None, **kwargs):
     if isinstance(fpath, six.string_types):
         fh = codecs.open(fpath, encoding='utf-8')
         if reader:
-            yield reader(fh, delimiter=kwargs.pop('delimiter', b'|'), lineterminator=kwargs.pop('lineterminator', ';'))
+            yield reader(fh, delimiter=kwargs.pop('delimiter', '|'), lineterminator=kwargs.pop('lineterminator', ';'))
         else:
             yield fh
 
@@ -58,49 +53,44 @@ def file_resolving(fpath, reader=None, **kwargs):
         yield fh
 
 
-def get_kbs(custom_kbs_files=None, cache={}):  # noqa
+def get_kbs(custom_kbs=None, cache={}, cache_inputs={}):  # noqa
     """Load kbs (with caching).
 
-    This function stores the loaded kbs into the cache variable
-    For the caching to work, it needs to receive an empty dictionary
-    as "cache" paramater.
+    This function stores the loaded kbs into the cache variable.
+    For the caching to work, it needs to receive empty dictionaries
+    as "cache" and "cache_inputs" parameters.
     """
+    kbs = CFG_REFEXTRACT_KBS.copy()
+    if custom_kbs:
+        kbs.update({kb_type: kb for (kb_type, kb) in custom_kbs.items() if kb})
 
-    cache_key = make_cache_key(custom_kbs_files)
-    if cache_key not in cache:
-        # Build paths from defaults and specified ones
-        kbs_files = CFG_REFEXTRACT_KBS.copy()
-        if custom_kbs_files:
-            for key, path in custom_kbs_files.items():
-                if path:
-                    kbs_files[key] = path
-        # Loads kbs from those paths
-        cache[cache_key] = load_kbs(kbs_files)
-    return cache[cache_key]
+    for kb_type, kb in kbs.items():
+        if kb != cache_inputs.get(kb_type):
+            cache_inputs[kb_type] = kb
+            cache[kb_type] = load_kb_by_type(kb_type, kb)
+    return cache
 
 
-def load_kbs(kbs_files):
-    """Load kbs (without caching)
+def load_kb_by_type(kb_type, kb):
+    """Load kb (without caching) for a given kb type."""
 
-    Args:
-    - kb_files: list of custom paths you can specify to override the
-                 default values
-    If path starts with "kb:", the kb will be loaded from the database
-    """
-
-    return {
-        'journals_re': build_journals_re_kb(kbs_files['journals-re']),
-        'journals': load_kb(kbs_files['journals'], build_journals_kb),
-        'report-numbers': build_reportnum_kb(kbs_files['report-numbers']),
-        'authors': build_authors_kb(kbs_files['authors']),
-        'books': build_books_kb(kbs_files['books']),
-        'publishers': load_kb(kbs_files['publishers'], build_publishers_kb),
-        'special_journals': build_special_journals_kb(kbs_files['special-journals']),
-        'collaborations': load_kb(kbs_files['collaborations'], build_collaborations_kb),
+    loaders = {
+        'journals_re': build_journals_re_kb,
+        'journals': lambda kb: load_kb(kb, build_journals_kb),
+        'report-numbers': build_reportnum_kb,
+        'authors': build_authors_kb,
+        'books': build_books_kb,
+        'publishers': lambda kb: load_kb(kb, build_publishers_kb),
+        'special_journals': build_special_journals_kb,
+        'collaborations': lambda kb: load_kb(kb, build_collaborations_kb),
     }
 
+    return loaders[kb_type](kb)
+
 
 def load_kb(path, builder):
+    if isinstance(path, dict):
+        return load_kb_from_iterable(path.items(), builder)
     try:
         path.startswith
     except AttributeError:
@@ -109,27 +99,6 @@ def load_kb(path, builder):
         return load_kb_from_file(path, builder)
 
 
-def make_cache_key(custom_kbs_files=None):
-    """Create cache key for kbs caches instances
-
-    This function generates a unique key for a given set of arguments.
-
-    The files dictionary is transformed like this:
-    {'journal': '/var/journal.kb', 'books': '/var/books.kb'}
-    to
-    "journal=/var/journal.kb;books=/var/books.kb"
-
-    Then _inspire is appended if we are an INSPIRE site.
-    """
-    if custom_kbs_files:
-        serialized_args = ('%s=%s' % v for v in iteritems(custom_kbs_files))
-        serialized_args = ';'.join(serialized_args)
-    else:
-        serialized_args = "default"
-    cache_key = md5(serialized_args).digest()
-    return cache_key
-
-
 def order_reportnum_patterns_bylen(numeration_patterns):
     """Given a list of user-defined patterns for recognising the numeration
        styles of an institute's preprint references, for each pattern,
@@ -141,20 +110,11 @@ def order_reportnum_patterns_bylen(numeration_patterns):
        @return: (list) of tuples, where each tuple contains a pattern and
         its length.
     """
-    def _compfunc_bylen(a, b):
-        """Compares regexp patterns by the length of the pattern-text.
-        """
-        if a[0] < b[0]:
-            return 1
-        elif a[0] == b[0]:
-            return 0
-        else:
-            return -1
     pattern_list = []
     for pattern in numeration_patterns:
         base_pattern = re_regexp_character_class.sub('1', pattern)
         pattern_list.append((len(base_pattern), pattern))
-    pattern_list.sort(_compfunc_bylen)
+    pattern_list.sort(key=lambda x: x[0], reverse=True)
     return pattern_list
 
 
@@ -309,9 +269,9 @@ def build_reportnum_kb(fpath):
             # complete regex:
             # will be in the style "(categ)-(numatn1|numatn2|numatn3|...)"
             for classification in preprint_classifications:
-                search_pattern_str = ur'(?:^|[^a-zA-Z0-9\/\.\-])([\[\(]?(?P<categ>' \
+                search_pattern_str = r'(?:^|[^a-zA-Z0-9\/\.\-])([\[\(]?(?P<categ>' \
                                      + classification[0].strip() + u')' \
-                                     + numeration_regexp + ur'[\]\)]?)'
+                                     + numeration_regexp + r'[\]\)]?)'
 
                 re_search_pattern = re.compile(search_pattern_str,
                                                re.UNICODE)
@@ -339,14 +299,14 @@ def build_reportnum_kb(fpath):
     # read from the KB
 
     # pattern to recognise an institute name line in the KB
-    re_institute_name = re.compile(ur'^\*{5}\s*(.+)\s*\*{5}$', re.UNICODE)
+    re_institute_name = re.compile(r'^\*{5}\s*(.+)\s*\*{5}$', re.UNICODE)
 
     # pattern to recognise an institute preprint categ line in the KB
     re_preprint_classification = \
-        re.compile(ur'^\s*(\w.*)\s*---\s*(\w.*)\s*$', re.UNICODE)
+        re.compile(r'^\s*(\w.*)\s*---\s*(\w.*)\s*$', re.UNICODE)
 
     # pattern to recognise a preprint numeration-style line in KB
-    re_numeration_pattern = re.compile(ur'^\<(.+)\>$', re.UNICODE)
+    re_numeration_pattern = re.compile(r'^\<(.+)\>$', re.UNICODE)
 
     kb_line_num = 0    # when making the dictionary of patterns, which is
     # keyed by the category search string, this counter
@@ -415,23 +375,6 @@ def build_reportnum_kb(fpath):
             standardised_preprint_reference_categories)
 
 
-def _cmp_bystrlen_reverse(a, b):
-    """A private "cmp" function to be used by the "sort" function of a
-       list when ordering the titles found in a knowledge base by string-
-       length - LONGEST -> SHORTEST.
-       @param a: (string)
-       @param b: (string)
-       @return: (integer) - 0 if len(a) == len(b); 1 if len(a) < len(b);
-        -1 if len(a) > len(b);
-    """
-    if len(a) > len(b):
-        return -1
-    elif len(a) < len(b):
-        return 1
-    else:
-        return 0
-
-
 def build_special_journals_kb(fpath):
     """Load special journals database from file
 
@@ -466,7 +409,7 @@ def build_publishers_kb(fpath):
     with file_resolving(fpath, reader=csv.reader, lineterminator='\n') as fh:
         publishers = {}
         for line in fh:
-            pattern = re.compile(ur'(\b|^)%s(\b|$)' % line[0], re.I | re.U)
+            pattern = re.compile(r'(\b|^)%s(\b|$)' % line[0], re.I | re.U)
             publishers[line[0]] = {'pattern': pattern, 'repl': line[1]}
 
     return publishers
@@ -530,8 +473,7 @@ def load_kb_from_file(path, builder):
             if m_kb_line:  # good KB line
                 yield m_kb_line.group('seek'), m_kb_line.group('repl')
             else:
-                raise StandardError("Badly formatted kb '%s' at line %s"
-                                    % (path, rawline))
+                raise ValueError("Badly formatted kb '%s' at line %s" % (path, rawline))
 
     with file_resolving(path) as fh:
         return builder(lazy_parser(fh))
@@ -587,7 +529,7 @@ def build_journals_kb(knowledgebase):
 
         # add the phrase from the KB if the 'seek' phrase is longer
         # compile the seek phrase into a pattern:
-        seek_ptn = re.compile(ur'(?<!\w)(%s)\W' % re.escape(seek_phrase),
+        seek_ptn = re.compile(r'(?<!\w)(%s)\W' % re.escape(seek_phrase),
                               re.UNICODE)
 
         kb[seek_phrase] = seek_ptn
@@ -605,14 +547,14 @@ def build_journals_kb(knowledgebase):
         if raw_repl_phrase not in kb:
             # The replace-phrase was not in the KB as a seek phrase
             # It should be added.
-            pattern = ur'(?<!\/)\b(%s)[^A-Z0-9]' % re.escape(raw_repl_phrase)
+            pattern = r'(?<!\/)\b(%s)[^A-Z0-9]' % re.escape(raw_repl_phrase)
             seek_ptn = re.compile(pattern, re.U)
             kb[raw_repl_phrase] = seek_ptn
             standardised_titles[raw_repl_phrase] = repl_term
             seek_phrases.append(raw_repl_phrase)
 
     # Sort the titles by string length (long - short)
-    seek_phrases.sort(_cmp_bystrlen_reverse)
+    seek_phrases.sort(key=len, reverse=True)
 
     # return the raw knowledge base:
     return kb, standardised_titles, seek_phrases
@@ -621,10 +563,10 @@ def build_journals_kb(knowledgebase):
 def build_collaborations_kb(knowledgebase):
     kb = {}
     for pattern, collab in knowledgebase:
-        prefix = ur"(?:^|[\(\"\[\s]|(?<=\W))\s*(?:(?:the|and)\s+)?"
-        collaboration_pattern = ur"(?:\s*coll(?:aborations?|\.)?)?"
-        suffix = ur"(?=$|[><\]\)\"\s.,:])"
-        pattern = pattern.replace(' ', '\s')
+        prefix = r"(?:^|[\(\"\[\s]|(?<=\W))\s*(?:(?:the|and)\s+)?"
+        collaboration_pattern = r"(?:\s*coll(?:aborations?|\.)?)?"
+        suffix = r"(?=$|[><\]\)\"\s.,:])"
+        pattern = pattern.replace(' ', r'\s')
         pattern = pattern.replace('Collaboration', collaboration_pattern)
         re_pattern = "%s(%s)%s" % (prefix, pattern, suffix)
         kb[collab] = re.compile(re_pattern, re.I | re.U)
