@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of refextract
-# Copyright (C) 2016, 2017, 2018 CERN.
+# Copyright (C) 2016, 2017, 2018, 2020 CERN.
 #
 # refextract is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -21,8 +21,6 @@
 # granted to it by virtue of its status as an Intergovernmental Organization
 # or submit itself to any jurisdiction.
 
-from __future__ import absolute_import, division, print_function
-
 import pytest
 
 from refextract.references.engine import (
@@ -336,7 +334,7 @@ def test_get_plaintext_document_body(tmpdir):
         f = tmpdir.join("page.html")
         f.write(html)
         get_plaintext_document_body(str(f))
-    assert 'text/html' in excinfo.value
+    assert 'text/html' in excinfo.value.args
 
 
 def test_reference_split():
@@ -436,13 +434,3 @@ def test_reference_split_handles_semicolon():
     res = get_references(ref_line)
     references = res[0]
     assert len(references) == 2
-
-
-def test_clean_pdf_before_run(tmp_path, pdf_files):
-    tmp_file_path = tmp_path / "packed.pdf"
-    pdf = pdf_files[7]
-    with open(pdf, 'rb') as input, open(tmp_file_path.as_posix(), 'wb') as tmp_out:
-        tmp_out.write(input.read())
-
-    text = get_plaintext_document_body(tmp_file_path.as_posix())
-    assert text == ['Test\n', '\x0c']
